# q2-clawback

[![Build Status](https://travis-ci.org/BenKaehler/q2-clawback.svg?branch=master)](https://travis-ci.org/BenKaehler/q2-clawback)

This is a QIIME 2 plugin. For details on QIIME 2, see https://qiime2.org.

For details on this plugin, please see the [tutorial](https://forum.qiime2.org/t/using-q2-clawback-to-assemble-taxonomic-weights/5859) or the [preprint](https://doi.org/10.1101/406611).
